==> prestashop-1.4.9.0.tbz: www/prestashop/mails/it/lang.php <==
<?php

global $_LANGMAIL;
$_LANGMAIL = array();
$_LANGMAIL['Welcome!'] = 'Benvenuti!';
$_LANGMAIL['Message from contact form'] = 'Messaggio da modulo di contatto';
$_LANGMAIL['Your message has been correctly sent'] = 'Il tuo messaggio è stato inviato correttamente';
$_LANGMAIL['New credit slip regarding your order'] = 'Nuova nota di credito riguardo al tuo ordine';
$_LANGMAIL['Virtual product to download'] = 'Prodotto virtuale da scaricare';
$_LANGMAIL['Fwd: Customer message'] = 'Messaggio cliente';
$_LANGMAIL['Your guest account has been transformed to customer account'] = 'Il tuo account ospite è stato trasformato in account cliente';
$_LANGMAIL['Package in transit'] = 'Pacco in viaggio';
$_LANGMAIL['[Log'] = '[Log';
$_LANGMAIL['Order confirmation'] = 'Conferma ordine';
$_LANGMAIL['Message from a customer'] = 'Messaggio da un cliente';
$_LANGMAIL['New message regarding your order'] = 'Nuovo messaggio riguardo al tuo ordine';
$_LANGMAIL['Your order return state has changed'] = 'Nuovo status dell\'ordine';
$_LANGMAIL['Your password'] = 'La tua password';
$_LANGMAIL['Password query confirmation'] = 'Conferma richiesta password';
$_LANGMAIL['An answer to your message is available'] = 'E\' disponibile una risposta al tuo messaggio';
$_LANGMAIL['New voucher regarding your order'] = 'Nuovo buono sconto riguardo al tuo ordine';
$_LANGMAIL['Happy birthday!'] = 'Buon compleanno!';
$_LANGMAIL['Newsletter confirmation'] = 'Conferma newsletter';
$_LANGMAIL['Newsletter voucher'] = 'Buono sconto newsletter';
$_LANGMAIL['Your wishlist\\\'s link'] = 'Il tuo collegamento alla lista dei desideri';
$_LANGMAIL['Message from '] = 'Messaggio da';
$_LANGMAIL['$subject'] = '$soggetto';
$_LANGMAIL['Your cart and your discount'] = 'Il tuo carrello e il tuo sconto';
$_LANGMAIL['Thanks for your order'] = 'Grazie dell\'ordine';
$_LANGMAIL['You are one of our best customers'] = 'Sei uno dei nostri clienti migliori';
$_LANGMAIL['We miss you'] = 'Ci manchi';
$_LANGMAIL['Product available'] = 'Prodotto disponibile';
$_LANGMAIL['Product out of stock'] = 'Prodotto esaurito';
$_LANGMAIL['Error reporting from your PayPal module'] = 'Errore dal tuo modulo PayPal';
$_LANGMAIL['Congratulations!'] = 'Congratulazioni!';
$_LANGMAIL['Referral Program'] = 'Programma di presentazione';
$_LANGMAIL['A friend sent you a link to'] = 'Un amico ti ha inviato un link per';
$_LANGMAIL['Log: You have a new alert from your shop'] = 'Log: Hai un nuovo Avviso dal tuo negozio';
$_LANGMAIL['Message from \').$customer->lastname.\' '] = 'Messaggio da:';
$_LANGMAIL[' $subject'] = 'Oggetto';
$_LANGMAIL['A friend sent you a link to\').\' '] = 'Un amico ti ha mandato il link';

?>

==> prestashop-1.5.3.1.tbz: www/prestashop/mails/it/lang.php <==
<?php

global $_LANGMAIL;
$_LANGMAIL = array();

$_LANGMAIL['New credit slip regarding your order'] = 'Nuova nota di credito riguardo al tuo ordine';
$_LANGMAIL['Your guest account has been transformed to customer account'] = 'Il tuo account ospite è stato trasformato in account cliente';
$_LANGMAIL['Message from a customer'] = 'Messaggio da un cliente';
$_LANGMAIL['Your new password'] = 'La tua nuova password';
$_LANGMAIL['Newsletter confirmation'] = 'Conferma newsletter';
$_LANGMAIL['Newsletter voucher'] = 'Buono sconto newsletter';
$_LANGMAIL['Message from %1$s %2$s'] = 'Messaggio da %1$s %2$s';
$_LANGMAIL['Your cart and your discount'] = 'Il tuo carrello e il tuo sconto';
$_LANGMAIL['%1$s sent you a link to %2$s'] = '%1$s invia il link a %2$s';
$_LANGMAIL['Package in transit'] = 'Pacco in viaggio';
$_LANGMAIL['Log: You have a new alert from your shop'] = 'Log: Hai un nuovo Avviso dal tuo negozio';
$_LANGMAIL['Password query confirmation'] = 'Conferma richiesta password';
$_LANGMAIL['An answer to your message is available #ct%1$s #tc%2$s'] = 'E\' disponibile una risposta al tuo messaggio #ct%1$s #tc%2$s';
$_LANGMAIL['You are one of our best customers'] = 'Sei uno dei nostri clienti migliori';
$_LANGMAIL['Welcome!'] = 'Benvenuti!';
$_LANGMAIL['Virtual product to download'] = 'Prodotto virtuale da scaricare';
$_LANGMAIL['Fwd: Customer message'] = 'Messaggio cliente';
$_LANGMAIL['Order confirmation'] = 'Conferma ordine';
$_LANGMAIL['New message regarding your order'] = 'Nuovo messaggio riguardo al tuo ordine';
$_LANGMAIL['New voucher regarding your order %s'] = 'Nuovo buono sconto riguardante il tuo ordine %s';
$_LANGMAIL['Thanks for your order'] = 'Grazie dell\'ordine';
$_LANGMAIL['We miss you'] = 'Ci manchi';
$_LANGMAIL['Congratulations!'] = 'Congratulazioni!';
$_LANGMAIL['Message from contact form'] = 'Messaggio da modulo di contatto';
$_LANGMAIL['Your message has been correctly sent'] = 'Il tuo messaggio è stato inviato correttamente';
$_LANGMAIL['Your order return state has changed'] = 'Nuovo status dell\'ordine';
$_LANGMAIL['Product available'] = 'Prodotto disponibile';
$_LANGMAIL['Product out of stock'] = 'Prodotto esaurito';
